@@ -315,7 +315,7 @@ class FieldmapEstimation:
 
         if fmap_types:
             sources = sorted(
-                str(f.path)
+                f.path
                 for f in self.sources
                 if f.suffix in ("fieldmap", "phasediff", "phase1", "phase2")
             )
@@ -325,7 +325,7 @@ class FieldmapEstimation:
             if sum(missing_phases) == 1:
                 mis_ph = "phase1" if missing_phases[0] else "phase2"
                 hit_ph = "phase2" if missing_phases[0] else "phase1"
-                new_source = sources[0].replace(hit_ph, mis_ph)
+                new_source = sources[0].parent / sources[0].name.replace(hit_ph, mis_ph)
                 self.sources.append(FieldmapFile(new_source))
                 sources.insert(int(missing_phases[1]), new_source)
 
@@ -336,14 +336,13 @@ class FieldmapEstimation:
             magnitude = f"magnitude{'' if self.method == EstimatorType.MAPPED else '1'}"
             if magnitude not in suffix_set:
                 try:
-                    self.sources.append(
-                        FieldmapFile(
-                            sources[0]
-                            .replace("fieldmap", "magnitude")
-                            .replace("diff", "1")
-                            .replace("phase", "magnitude")
-                        )
+                    new_path = (
+                        sources[0].parent / sources[0].name
+                        .replace("fieldmap", "magnitude")
+                        .replace("diff", "1")
+                        .replace("phase", "magnitude")
                     )
+                    self.sources.append(FieldmapFile(new_path))
                 except Exception:
                     raise ValueError(
                         "A fieldmap or phase-difference estimation type was found, "
@@ -356,13 +355,12 @@ class FieldmapEstimation:
                 and "magnitude2" not in suffix_set
             ):
                 try:
-                    self.sources.append(
-                        FieldmapFile(
-                            sources[-1]
-                            .replace("diff", "2")
-                            .replace("phase", "magnitude")
-                        )
+                    new_path = (
+                        sources[-1].parent / sources[-1].name
+                        .replace("diff", "2")
+                        .replace("phase", "magnitude")
                     )
+                    self.sources.append(FieldmapFile(new_path))
                 except Exception:
                     if "phase2" in suffix_set:
                         raise ValueError(
@@ -406,27 +404,31 @@ class FieldmapEstimation:
         # Register this estimation method
         if not self.bids_id:
             # If not manually set, try to get it from BIDS metadata
-            bids_ids = set(
-                [
-                    f.metadata.get("B0FieldIdentifier")
-                    for f in self.sources
-                    if f.metadata.get("B0FieldIdentifier")
-                ]
-            )
-            if len(bids_ids) > 1:
-                raise ValueError(
-                    f"Multiple ``B0FieldIdentifier`` set: <{', '.join(bids_ids)}>"
-                )
-            elif bids_ids:
+            b0_ids = [
+                listify(f.metadata.get("B0FieldIdentifier"))
+                for f in self.sources
+                if f.metadata.get("B0FieldIdentifier")
+            ]
+
+            if b0_ids:
+                # Find common IDs
+                bids_ids = set(b0_ids[0]).intersection(*b0_ids[1:])
+                if not bids_ids:
+                    raise ValueError(
+                        f"No common ``B0FieldIdentifier`` found: <{', '.join(map(str, b0_ids))}>"
+                    )
+                elif len(bids_ids) > 1:
+                    raise ValueError(
+                        f"Multiple common ``B0FieldIdentifier``s found: <{', '.join(bids_ids)}>"
+                    )
                 object.__setattr__(self, "bids_id", bids_ids.pop())
-            else:
-                bids_id = _estimators.add(self.paths())
-                object.__setattr__(self, "bids_id", bids_id)
-                for intent_file in intents_meta:
-                    _intents[intent_file].add(bids_id)
-                return
+
+        if self.bids_id:
+            _estimators[self.bids_id] = self.paths()
+        else:
+            bids_id = _estimators.add(self.paths())
+            object.__setattr__(self, "bids_id", bids_id)
 
-        _estimators[self.bids_id] = self.paths()
         for intent_file in intents_meta:
             _intents[intent_file].add(self.bids_id)
 
